@@ -7,6 +7,18 @@ jamesList  = []
 sarahList  = []
 mikeyList  = []
 
+'''four new lists for storing the ordered and uniformed lists from original lists'''
+sanitizedJames = []
+sanitizedJulie = []
+sanitizedMikey = []
+sanitizedSarah = []
+
+'''new lists for removing the duplicates and displaying the top 3 plays' time'''
+uniqueJames = []
+uniqueJulie = []
+uniqueMikey = []
+uniqueSarah = []
+        
 def sanitize(time_string):
     if '-' in time_string:
         splitter = '-'
@@ -18,12 +30,26 @@ def sanitize(time_string):
     (mins, secs) = time_string.split(splitter)
     return (mins + '.' + secs)
 
+def getFiles(file_name):
+    try:
+        with open(file_name) as fileSubject:
+            data = fileSubject.readline()
+            return data.strip().split(',')
+
+    except IOError as err:
+        print("File IO Error:", + str(err))
 
 def getData():
     try:
+        jamesList = getFiles('james.txt')
+        julieList = getFiles('julie.txt')
+        mikeyList = getFiles('mikey.txt')
+        sarahList = getFiles('sarah.txt')
+        '''
         with open('james.txt') as james:
             data = james.readline()
             jamesList = data.strip().split(',')
+        
         with open('julie.txt') as julie:
             data = julie.readline()
             julieList = data.strip().split(',')
@@ -33,18 +59,8 @@ def getData():
         with open('sarah.txt') as sarah:
             data = sarah.readline()
             sarahList = data.strip().split(',')
-        '''four new lists for storing the ordered and uniformed lists from original lists'''
-        sanitizedJames = []
-        sanitizedJulie = []
-        sanitizedMikey = []
-        sanitizedSarah = []
-
-        '''new lists for removing the duplicates and displaying the top 3 plays' time'''
-        uniqueJames = []
-        uniqueJulie = []
-        uniqueMikey = []
-        uniqueSarah = []
-
+        '''
+            
         '''for item in jamesList:
             sanitizedJames.append(sanitize(item))'''
         '''the below code is a new way for list comprehension'''
@@ -59,6 +75,14 @@ def getData():
             sanitizedSarah.append(sanitize(item))'''
         sanitizedSarah = sorted([sanitize(each_item) for each_item in sarahList])
 
+        print("now print the non-duplication result using set() rather than list()")
+        print(sorted(set(sanitize(t) for t in jamesList))[0:3])
+        print(sorted(set(sanitize(t) for t in julieList))[0:3])
+        print(sorted(set(sanitize(t) for t in mikeyList))[0:3])
+        print(sorted(set(sanitize(t) for t in sarahList))[0:3])
+        
+        '''now refiene the code for removing the duplicates using set() rather than list()'''
+        
         for each_item in sanitizedJames:
             if each_item not in uniqueJames:
                 uniqueJames.append(each_item)
@@ -81,7 +105,7 @@ def getData():
         print("James:", uniqueMikey[0:3])
         print("Julie:", uniqueSarah[0:3])
 
-
+        '''
         print("now print the sorted athletes' list in asending order:")
         print(sanitizedJames)       
         print(sanitizedJulie)       
@@ -93,7 +117,7 @@ def getData():
         print(sorted(sanitizedJulie, reverse = True))       
         print(sorted(sanitizedMikey, reverse = True))       
         print(sorted(sanitizedSarah, reverse = True))
-
+        '''
         
 
 #        print(jamesList)
